@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-06-30'; # DATE
-our $VERSION = '1.52'; # VERSION
+our $DATE = '2015-07-08'; # DATE
+our $VERSION = '1.53'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -173,29 +173,32 @@ sub BUILD {
             $_t->('help'),
             show_in_options => sub { $ENV{VERBOSE} },
         };
-        $copts->{format} = {
-            $_t->('format'),
-            schema => ['str*' => in => $formats],
-        };
-        # XXX support --naked-res
-        $copts->{json} = {
-            $_t->('json'),
-            summary => N__("Equivalent to --format=json-pretty"),
-            handler => sub {
-                my ($go, $val, $r) = @_;
-                $r->{format} = 'json-pretty';
-            },
-        };
-        $copts->{format_options} = {
-            getopt  => "format-options=s",
-            summary => N__("Pass options to formatter"),
-            handler => sub {
-                my ($go, $val, $r) = @_;
-                $r->{format_options} = __json_decode($val);
-            },
-            is_settable_via_config => 1,
-            tags => ['category:output'],
-        };
+
+        unless ($self->skip_format) {
+            $copts->{format} = {
+                $_t->('format'),
+                schema => ['str*' => in => $formats],
+            };
+            # XXX support --naked-res
+            $copts->{json} = {
+                $_t->('json'),
+                summary => N__("Equivalent to --format=json-pretty"),
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{format} = 'json-pretty';
+                },
+            };
+            $copts->{format_options} = {
+                getopt  => "format-options=s",
+                summary => N__("Pass options to formatter"),
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{format_options} = __json_decode($val);
+                },
+                is_settable_via_config => 1,
+                tags => ['category:output'],
+            };
+        }
 
         if ($self->subcommands) {
             $copts->{subcommands} = {
@@ -560,7 +563,7 @@ sub action_subcommands {
 
     if (!$self->subcommands) {
         return [200, "OK", __("There are no subcommands") . ".",
-                {"x.perinci.cmdline._skip_format"=>1}];
+                {"cmdline.skip_format"=>1}];
     }
 
     $r->{_help_buf} = '';
@@ -605,7 +608,7 @@ sub action_subcommands {
     $self->_help_draw_curtbl($r);
 
     [200, "OK", $r->{_help_buf},
-     {"x.perinci.cmdline._skip_format"=>1}];
+     {"cmdline.skip_format"=>1}];
 }
 
 sub action_version {
@@ -647,7 +650,7 @@ sub action_version {
         ($Perinci::CmdLine::Classic::DATE ? " ($Perinci::CmdLine::Classic::DATE)" : ""),
         "\n";
 
-    [200, "OK", join("", @text), {"x.perinci.cmdline._skip_format"=>1}];
+    [200, "OK", join("", @text), {"cmdline.skip_format"=>1}];
 }
 
 sub action_call {
@@ -764,7 +767,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.52 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-06-30.
+This document describes version 1.53 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-07-08.
 
 =head1 SYNOPSIS
 
