@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic::Role::Help;
 
-our $DATE = '2015-06-30'; # DATE
-our $VERSION = '1.52'; # VERSION
+our $DATE = '2015-07-08'; # DATE
+our $VERSION = '1.53'; # VERSION
 
 # split here just so it's more organized
 
@@ -493,7 +493,7 @@ sub action_help {
         $self->$meth($r);
     }
     $self->_help_draw_curtbl($r);
-    [200, "OK", $r->{_help_buf}, {"x.perinci.cmdline.skip_format"=>1}];
+    [200, "OK", $r->{_help_buf}, {"cmdline.skip_format"=>1}];
 }
 
 1;
@@ -511,7 +511,7 @@ Perinci::CmdLine::Classic::Role::Help - Help-related routines
 
 =head1 VERSION
 
-This document describes version 1.52 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-06-30.
+This document describes version 1.53 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-07-08.
 
 =for Pod::Coverage ^(.+)$
 
